@@ -34,6 +34,7 @@ from vdsm.network.netinfo import bridges
 from vdsm.network.netinfo import mtus
 from vdsm.network.netinfo import nics as netinfo_nics
 from vdsm.network.netinfo.cache import CachingNetInfo
+from vdsm.network.link import iface as link_iface
 from vdsm.network.ip.address import IPv4, IPv6
 from vdsm import utils
 
@@ -260,9 +261,15 @@ def _validate_inter_network_compatibility(ni, vlan, iface):
 
 
 def _update_mtu_for_an_existing_bridge(dev_name, configurator, mtu):
+    # When the MTU changes to the default MTU, reading the existing MTU on the
+    # bridge is misleading, as with the latest OS, when no ports are connected
+    # to it, it will fall down to the default.
+    # In such a scenario, the ifcfg file still needs to be updated.
     if mtu != mtus.getMtu(dev_name):
         configurator.configApplier.setIfaceMtu(dev_name, mtu)
         _update_bridge_ports_mtu(dev_name, mtu)
+    elif mtu == link_iface.DEFAULT_MTU:
+        configurator.configApplier.setIfaceMtu(dev_name, mtu)
 
 
 def _update_bridge_ports_mtu(bridge, mtu):
